@@ -21,8 +21,10 @@
 #include "utility/spdlog-fmt.hpp"
 
 // libraries
+#include "XLink/XLink.h"
 #include "spdlog/fmt/chrono.h"
 #include "spdlog/spdlog.h"
+#include "utility/Logging.hpp"
 #include "zlib.h"
 
 // Resource compiled assets (cmds)
@@ -144,7 +146,7 @@ std::vector<uint8_t> DeviceBootloader::createDepthaiApplicationPackage(
         deviceFirmware = std::move(compressBuffer);
 
         auto diff = duration_cast<milliseconds>(steady_clock::now() - t1);
-        spdlog::debug("Compressed firmware for Dephai Application Package. Took {}, size reduced from {:.2f}MiB to {:.2f}MiB",
+        logger::debug("Compressed firmware for Dephai Application Package. Took {}, size reduced from {:.2f}MiB to {:.2f}MiB",
                       diff,
                       prevSize / (1024.0f * 1024.0f),
                       deviceFirmware.size() / (1024.0f * 1024.0f));
@@ -218,11 +220,11 @@ std::vector<uint8_t> DeviceBootloader::createDepthaiApplicationPackage(
     for(std::size_t i = 0; i < assetStorage.size(); i++) fwPackage[assetStorageSection->offset + i] = assetStorage[i];
 
     // Debug
-    if(spdlog::get_level() == spdlog::level::debug) {
+    if(logger::get_level() == spdlog::level::debug) {
         SBR_SECTION* cur = &sbr.sections[0];
-        spdlog::debug("DepthAI Application Package");
+        logger::debug("DepthAI Application Package");
         for(; cur != lastSection + 1; cur++) {
-            spdlog::debug("{}, {}B, {}, {}, {}, {}", cur->name, cur->size, cur->offset, cur->checksum, cur->type, cur->flags);
+            logger::debug("{}, {}B, {}, {}, {}, {}", cur->name, cur->size, cur->offset, cur->checksum, cur->type, cur->flags);
         }
     }
 
@@ -267,12 +269,28 @@ DeviceBootloader::DeviceBootloader(const DeviceInfo& devInfo, const dai::Path& p
     init(false, pathToBootloader, tl::nullopt, allowFlashingBootloader);
 }
 
+DeviceBootloader::DeviceBootloader(std::string nameOrDeviceId, bool allowFlashingBootloader) : deviceInfo(std::move(nameOrDeviceId)) {
+    init(true, {}, tl::nullopt, allowFlashingBootloader);
+}
+
 void DeviceBootloader::init(bool embeddedMvcmd, const dai::Path& pathToMvcmd, tl::optional<bootloader::Type> type, bool allowBlFlash) {
     stream = nullptr;
     allowFlashingBootloader = allowBlFlash;
 
     bootloaderType = type.value_or(DEFAULT_TYPE);
 
+    // If deviceInfo isn't fully specified (eg ANY_STATE, etc...), but id or name is - try finding it first
+    if((deviceInfo.state == X_LINK_ANY_STATE || deviceInfo.protocol == X_LINK_ANY_PROTOCOL) && (!deviceInfo.mxid.empty() || !deviceInfo.name.empty())) {
+        deviceDesc_t foundDesc;
+        auto ret = XLinkFindFirstSuitableDevice(deviceInfo.getXLinkDeviceDesc(), &foundDesc);
+        if(ret == X_LINK_SUCCESS) {
+            deviceInfo = DeviceInfo(foundDesc);
+            logger::debug("Found an actual device by given DeviceInfo: {}", deviceInfo.toString());
+        } else {
+            throw std::runtime_error("Specified device not found");
+        }
+    }
+
     // Init device (if bootloader, handle correctly - issue USB boot command)
     if(deviceInfo.state == X_LINK_UNBOOTED) {
         // Unbooted device found, boot to BOOTLOADER and connect with XLinkConnection constructor
@@ -496,7 +514,7 @@ void DeviceBootloader::init(bool embeddedMvcmd, const dai::Path& pathToMvcmd, tl
             // Bump checking thread to not cause spurious warnings/closes
             std::chrono::milliseconds watchdogTimeout = std::chrono::milliseconds(3000);
             if(watchdogRunning && std::chrono::steady_clock::now() - prevPingTime > watchdogTimeout * 2) {
-                spdlog::warn("Monitor thread (device: {} [{}]) - ping was missed, closing the device connection", deviceInfo.mxid, deviceInfo.name);
+                logger::warn("Monitor thread (device: {} [{}]) - ping was missed, closing the device connection", deviceInfo.mxid, deviceInfo.name);
                 // ping was missed, reset the device
                 watchdogRunning = false;
                 // close the underlying connection
@@ -506,9 +524,9 @@ void DeviceBootloader::init(bool embeddedMvcmd, const dai::Path& pathToMvcmd, tl
     });
 
     // Bootloader device ready, check for version
-    spdlog::debug("Connected bootloader version {}", version.toString());
+    logger::debug("Connected bootloader version {}", version.toString());
     if(getEmbeddedBootloaderVersion() > version) {
-        spdlog::info("New bootloader version available. Device has: {}, available: {}", version.toString(), getEmbeddedBootloaderVersion().toString());
+        logger::info("New bootloader version available. Device has: {}, available: {}", version.toString(), getEmbeddedBootloaderVersion().toString());
     }
 }
 
@@ -518,7 +536,7 @@ void DeviceBootloader::close() {
 
     using namespace std::chrono;
     auto t1 = steady_clock::now();
-    spdlog::debug("DeviceBootloader about to be closed...");
+    logger::debug("DeviceBootloader about to be closed...");
 
     // Close connection first; causes Xlink internal calls to unblock semaphore waits and
     // return error codes, which then allows queues to unblock
@@ -539,17 +557,17 @@ void DeviceBootloader::close() {
     // BUGBUG investigate ownership; can another thread accessing this at the same time?
     stream = nullptr;
 
-    spdlog::debug("DeviceBootloader closed, {}", duration_cast<milliseconds>(steady_clock::now() - t1).count());
+    logger::debug("DeviceBootloader closed, {}", duration_cast<milliseconds>(steady_clock::now() - t1).count());
 }
 
+// This function is thread-unsafe. The idea of "isClosed" is ephemerial and
+// is invalid even within this function between the evaluation of the logical OR.
+// The calculated boolean and then then return by value continue to degrade in
+// validity to the caller
 bool DeviceBootloader::isClosed() const {
     return closed || !watchdogRunning;
 }
 
-void DeviceBootloader::checkClosed() const {
-    if(isClosed()) throw std::invalid_argument("DeviceBootloader already closed or disconnected");
-}
-
 DeviceBootloader::~DeviceBootloader() {
     close();
 }
@@ -646,7 +664,7 @@ DeviceBootloader::ApplicationInfo DeviceBootloader::readApplicationInfo(Memory m
 DeviceBootloader::MemoryInfo DeviceBootloader::getMemoryInfo(Memory memory) {
     if(memory == Memory::EMMC && bootloaderType == Type::USB) {
         // Warn, as result of "no emmc" might be deceiving
-        spdlog::warn("USB Bootloader type does NOT support eMMC");
+        logger::warn("USB Bootloader type does NOT support eMMC");
     }
 
     // Send request to retrieve bootloader version
@@ -701,9 +719,10 @@ std::tuple<bool, std::string> DeviceBootloader::flashDepthaiApplicationPackage(s
                                                                                std::vector<uint8_t> package,
                                                                                Memory memory) {
     // Bug in NETWORK bootloader in version 0.0.12 < 0.0.14 - flashing can cause a soft brick
-    auto version = getVersion();
-    if(bootloaderType == Type::NETWORK && version < Version(0, 0, 14)) {
-        throw std::invalid_argument("Network bootloader requires version 0.0.14 or higher to flash applications. Current version: " + version.toString());
+    auto bootloaderVersion = getVersion();
+    if(bootloaderType == Type::NETWORK && bootloaderVersion < Version(0, 0, 14)) {
+        throw std::invalid_argument("Network bootloader requires version 0.0.14 or higher to flash applications. Current version: "
+                                    + bootloaderVersion.toString());
     }
 
     std::tuple<bool, std::string> ret;
@@ -769,7 +788,7 @@ std::tuple<bool, std::string> DeviceBootloader::flashDepthaiApplicationPackage(s
         try {
             configJson = readConfigData();
         } catch(const std::exception& ex) {
-            spdlog::debug("Error while trying to read existing bootloader configuration: {}", ex.what());
+            logger::debug("Error while trying to read existing bootloader configuration: {}", ex.what());
         }
         // Set the following field 'appMem' (in forward/backward compat manner)
         configJson["appMem"] = finalAppMem;
@@ -778,12 +797,12 @@ std::tuple<bool, std::string> DeviceBootloader::flashDepthaiApplicationPackage(s
         std::string errorMsg;
         std::tie(success, errorMsg) = flashConfigData(configJson);
         if(success) {
-            spdlog::debug("Success flashing the appMem configuration to '{}'", static_cast<std::int32_t>(finalAppMem));
+            logger::debug("Success flashing the appMem configuration to '{}'", static_cast<std::int32_t>(finalAppMem));
         } else {
             throw std::runtime_error(errorMsg);
         }
     } catch(const std::exception& ex) {
-        spdlog::debug("Error while trying to specify final appMem configuration: {}", ex.what());
+        logger::debug("Error while trying to specify final appMem configuration: {}", ex.what());
     }
 
     return ret;
@@ -963,7 +982,7 @@ std::tuple<bool, std::string> DeviceBootloader::flashUserBootloader(std::functio
     try {
         configJson = readConfigData();
     } catch(const std::exception& ex) {
-        spdlog::debug("Error while trying to read existing bootloader configuration: {}", ex.what());
+        logger::debug("Error while trying to read existing bootloader configuration: {}", ex.what());
     }
     // Set the userBl fields (in forward/backward compat manner)
     const auto userBlSize = static_cast<std::uint32_t>(package.size());
@@ -975,7 +994,7 @@ std::tuple<bool, std::string> DeviceBootloader::flashUserBootloader(std::functio
     std::string errorMsg;
     std::tie(success, errorMsg) = flashConfigData(configJson);
     if(success) {
-        spdlog::debug("Success flashing the configuration userBlSize to '{}' and userBlChecksum to '{}'", userBlSize, userBlChecksum);
+        logger::debug("Success flashing the configuration userBlSize to '{}' and userBlChecksum to '{}'", userBlSize, userBlChecksum);
     } else {
         throw std::runtime_error(errorMsg);
     }
@@ -1085,8 +1104,8 @@ std::tuple<bool, std::string> DeviceBootloader::flashCustom(
     std::vector<uint8_t> optFileData;
     if(!filename.empty()) {
         // Read file into memory first
-        std::ifstream stream(filename, std::ios::in | std::ios::binary);
-        optFileData = std::vector<std::uint8_t>(std::istreambuf_iterator<char>(stream), {});
+        std::ifstream optFile(filename, std::ios::in | std::ios::binary);
+        optFileData = std::vector<std::uint8_t>(std::istreambuf_iterator<char>(optFile), {});
         data = optFileData.data();
         size = optFileData.size();
     }
@@ -1108,17 +1127,17 @@ std::tuple<bool, std::string> DeviceBootloader::flashCustom(
     result.success = 0;  // TODO remove these inits after fix https://github.com/luxonis/depthai-bootloader-shared/issues/4
     result.errorMsg[0] = 0;
     do {
-        std::vector<uint8_t> data;
-        if(!receiveResponseData(data)) return {false, "Couldn't receive bootloader response"};
+        std::vector<uint8_t> responseData;
+        if(!receiveResponseData(responseData)) return {false, "Couldn't receive bootloader response"};
 
         Response::FlashStatusUpdate update;
-        if(parseResponse(data, update)) {
+        if(parseResponse(responseData, update)) {
             // if progress callback is set
             if(progressCb != nullptr) {
                 progressCb(update.progress);
             }
             // if flash complete response arrived, break from while loop
-        } else if(parseResponse(data, result)) {
+        } else if(parseResponse(responseData, result)) {
             break;
         } else {
             // Unknown response, shouldn't happen
