@@ -50,23 +50,23 @@ std::string ColorCamera::getCamera() const {
 }
 
 // Set which color camera to use
-void ColorCamera::setCamId(int64_t id) {
+void ColorCamera::setCamId(int64_t camId) {
     // cast to board socket
-    switch(id) {
+    switch(camId) {
         case 0:
-            properties.boardSocket = CameraBoardSocket::RGB;
+            properties.boardSocket = CameraBoardSocket::CAM_A;
             break;
         case 1:
-            properties.boardSocket = CameraBoardSocket::LEFT;
+            properties.boardSocket = CameraBoardSocket::CAM_B;
             break;
         case 2:
-            properties.boardSocket = CameraBoardSocket::RIGHT;
+            properties.boardSocket = CameraBoardSocket::CAM_C;
             break;
         case 3:
             properties.boardSocket = CameraBoardSocket::CAM_D;
             break;
         default:
-            throw std::invalid_argument(fmt::format("CamId value: {} is invalid.", id));
+            throw std::invalid_argument(fmt::format("CamId value: {} is invalid.", camId));
             break;
     }
 }
@@ -177,6 +177,10 @@ void ColorCamera::setFps(float fps) {
     properties.fps = fps;
 }
 
+void ColorCamera::setIsp3aFps(int isp3aFps) {
+    properties.isp3aFps = isp3aFps;
+}
+
 void ColorCamera::setFrameEventFilter(const std::vector<dai::FrameEvent>& events) {
     properties.eventFilter = events;
 }
@@ -486,12 +490,12 @@ bool ColorCamera::getPreviewKeepAspectRatio() {
     return properties.previewKeepAspectRatio;
 }
 
-void ColorCamera::setNumFramesPool(int raw, int isp, int preview, int video, int still) {
-    properties.numFramesPoolRaw = raw;
-    properties.numFramesPoolIsp = isp;
-    properties.numFramesPoolPreview = preview;
-    properties.numFramesPoolVideo = video;
-    properties.numFramesPoolStill = still;
+void ColorCamera::setNumFramesPool(int numRaw, int numIsp, int numPreview, int numVideo, int numStill) {
+    properties.numFramesPoolRaw = numRaw;
+    properties.numFramesPoolIsp = numIsp;
+    properties.numFramesPoolPreview = numPreview;
+    properties.numFramesPoolVideo = numVideo;
+    properties.numFramesPoolStill = numStill;
 }
 
 void ColorCamera::setPreviewNumFramesPool(int num) {
@@ -526,5 +530,9 @@ int ColorCamera::getIspNumFramesPool() {
     return properties.numFramesPoolIsp;
 }
 
+void ColorCamera::setRawOutputPacked(bool packed) {
+    properties.rawPacked = packed;
+}
+
 }  // namespace node
 }  // namespace dai
