@@ -6,6 +6,9 @@
 #include <mutex>
 #include <unordered_map>
 
+// project
+#include <utility/Logging.hpp>
+
 namespace dai {
 namespace utility {
 
@@ -13,6 +16,10 @@ static std::mutex mtx;
 static std::unordered_map<std::string, std::string> map;
 
 std::string getEnv(const std::string& var) {
+    return getEnv(var, Logging::getInstance().logger);
+}
+
+std::string getEnv(const std::string& var, spdlog::logger& logger) {
     std::unique_lock<std::mutex> lock(mtx);
 
     if(map.count(var) > 0) {
@@ -23,7 +30,7 @@ std::string getEnv(const std::string& var) {
 
     // Log if env variable is set
     if(!value.empty()) {
-        spdlog::debug("Environment '{}' set to '{}'", var, value);
+        logger.debug("Environment '{}' set to '{}'", var, value);
     }
 
     return value;
